summaryrefslogtreecommitdiffstats
path: root/kdecore/netwm_def.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /kdecore/netwm_def.h
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdecore/netwm_def.h')
-rw-r--r--kdecore/netwm_def.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kdecore/netwm_def.h b/kdecore/netwm_def.h
index 1f6860243..fce97c445 100644
--- a/kdecore/netwm_def.h
+++ b/kdecore/netwm_def.h
@@ -340,10 +340,10 @@ public:
enum { AllTypesMask = 0LU-1 };
/**
* Returns true if the given window type matches the mask given
* using WindowTypeMask flags.
*/
- static bool typeMatchesMask( WindowType type, unsigned long mask );
+ static bool typeMatchesMask( WindowType type, unsigned long tqmask );
/**
Window state.
@@ -643,7 +643,7 @@ public:
};
/**
- Starting corner for desktop layout.
+ Starting corner for desktop tqlayout.
**/
enum DesktopLayoutCorner {
DesktopLayoutCornerTopLeft = 0,
@@ -340,10 +340,10 @@ public:
enum { AllTypesMask = 0LU-1 };
/**
- * Returns true if the given window type matches the mask given
+ * Returns true if the given window type matches the tqmask given
* using WindowTypeMask flags.
*/